Module fragment

Module fragment 

Fragment tree — the output of layout.

Each fragment represents a positioned, sized piece of the layout output, corresponding to a box tree node.

Structs

Fragment
A fragment produced by layout.
LayoutOutput
Layout output for a single node.
LayoutResult
The result of a layout computation.

Enums

FragmentKind
The kind of fragment.