Fragment tree — the output of layout.
Each fragment represents a positioned, sized piece of the layout output, corresponding to a box tree node.
Structs
- Fragment
- A fragment produced by layout.
- Layout
Output - Layout output for a single node.
- Layout
Result - The result of a layout computation.
Enums
- Fragment
Kind - The kind of fragment.